# Описание

Укажите краткую информацию об изменениях и о том, какая проблема устранена. Пожалуйста, также укажите соответствующую мотивацию и контекст.

Исправления # (issue)

## Тип изменения

Удалите неактуальные варианты.

- [ ] Документация (опечатки, примеры кода или любые другие обновления документации)
- [ ] Исправление бага (некритическое изменение, которое устраняет проблему)
- [ ] Новый функционал (некритическое изменение, добавляющее функциональность)
- [ ] Критические изменения (исправление или функционал, из-за которого существующая функциональность не будет работать должным образом)
- [ ] Это изменение требует обновления документации.

# Как это было протестировано?

Опишите тесты, которые вы провели для проверки изменений. Предоставьте инструкции, чтобы мы могли воспроизвести. Также укажите все необходимые сведения для вашей тестовой конфигурации.

- [ ] Test A
- [ ] Test B

**Тестовая конфигурация**:
* Операционная система:
* Версия Python:

# Контрольный список:

- [ ] Мой код соответствует рекомендациям по стилю этого проекта
- [ ] Я выполнил самопроверку своего собственного кода
- [ ] Я внес соответствующие изменения в документацию
- [ ] Я добавил тесты, которые доказывают, что мое исправление эффективно или моя функция работает
- [ ] Новые и существующие модульные тесты проходят локально с моими изменениями
